@@ -17,11 +17,13 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include <config.h>
+
 #include <memory.h>
 
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <gkbd-indicator.h>
 #include <gkbd-indicator-marshal.h>
